using System;
using System.Collections.Specialized;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Web;
using System.Web.UI;

namespace store_starter {

	/// <summary>
	/// Encompases general store state and procedures.  Every page in the store
	/// deals with login, so that stuff is here, they all deal with the database ...
	/// </summary>
	public class StoreContext {
		private Page page;

		// login instance vars
		private string activeUser; 
		private int activeUserID; 

		// database instance vars (*hint*)

		/// <summary>
		/// Set up a new instance of store context.  Check for persisting state things like
		/// session state and cookie state.
		/// </summary>
		/// <param name="page">A reference to the page object of the current form</param>
		public StoreContext(Page page) {
		
			// initialize class variables
			this.page = page;

			activeUser = "";

			if(page.Session["activeUser"] != null && page.Session["activeUser"].ToString() != ""){
				activeUser = (String)page.Session["activeUser"];
				activeUserID = (int)page.Session["activeUserID"];
			} else {
				if(page.Request.Cookies["storeLogin"] != null){ 
					HttpCookie loginCookie = page.Request.Cookies["storeLogin"];
					HttpCookie passwordCookie = page.Request.Cookies["storePassword"];

					/* Check database to make sure username/password is valid*/
					int userID = 0;

					if(false/* if username passowrd is valid */){
						activeUser = loginCookie.Value;
						activeUserID = userID;
					}
				}
			}


		}

		/// <summary>
		/// Is true when a user is logged in
		/// </summary>
		public bool UserLoggedIn{
			get {
				return activeUser != null && activeUser != "";
			}
		}

		/// <summary>
		/// Gets the logged in user's email address
		/// </summary>
		public string ActiveUser{
			get {
				return activeUser;
			}
		}

		/// <summary>
		/// Gets the logged in user's unique ID (int for me, maybe string for you)
		/// </summary>
		public int ActiveUserID{
			get {
				return activeUserID;
			}
		}

		/// <summary>
		/// Log a user out ...
		/// </summary>
		public void UserLogout(){
			page.Session["activeUser"] = "";
			page.Session["activeUserID"] = 0;
		}

		/// <summary>
		/// Log a user in
		/// </summary>
		/// <param name="email">Email of the user logging in</param>
		/// <param name="id">ID of the user logging in</param>
		public void UserLogin(string email, int id){
			page.Session["activeUser"] = email;
			page.Session["activeUserID"] = id;
		}

	}
}
